pecos.qeclib.steane.gates\_sq
=============================

.. automodule:: pecos.qeclib.steane.gates_sq



















.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   pecos.qeclib.steane.gates_sq.face_rots
   pecos.qeclib.steane.gates_sq.hadamards
   pecos.qeclib.steane.gates_sq.paulis
   pecos.qeclib.steane.gates_sq.sqrt_paulis
